# Pull Request

## Description

<!-- Provide a brief description of the changes introduced by this PR -->

## Type of Change

<!-- Mark the relevant option with an [x] -->

- [ ] 🐛 Bug fix (non-breaking change which fixes an issue)
- [ ] ✨ New feature (non-breaking change which adds functionality)
- [ ] 💥 Breaking change (fix or feature that would cause existing functionality to not work as expected)
- [ ] 📚 Documentation update
- [ ] 🧹 Code cleanup/refactoring
- [ ] 🔧 Build/CI changes
- [ ] 🧪 Test improvements
- [ ] 🔒 Security improvements

## Changes Made

<!-- List the main changes made in this PR -->

-
-
-

## Services/APIs Affected

<!-- Check all that apply -->

- [ ] Nalo Solutions
  - [ ] Payments
  - [ ] SMS
  - [ ] Email
  - [ ] USSD
- [ ] Configuration utilities
- [ ] Documentation
- [ ] Tests
- [ ] Other: ****\_\_\_****

## Testing

<!-- Describe the tests you ran to verify your changes -->

### Test Coverage

- [ ] All existing tests pass
- [ ] New tests added for new functionality
- [ ] Test coverage maintained/improved
- [ ] Manual testing completed

### Test Commands

```bash
# List the commands used to test the changes
python3 -m pytest tests/ -v
# Add any specific test commands here
```

## Breaking Changes

<!-- If this is a breaking change, describe what breaks and how users should adapt -->

- [ ] No breaking changes
- [ ] Breaking changes (describe below):

<!-- If breaking changes exist, provide migration guide -->

## Documentation

<!-- Check all that apply -->

- [ ] Code comments updated
- [ ] README.md updated
- [ ] API documentation updated
- [ ] Examples updated
- [ ] Changelog updated
- [ ] No documentation changes needed

## Dependencies

<!-- List any new dependencies or version changes -->

- [ ] No new dependencies
- [ ] New dependencies added:
  -
- [ ] Dependency versions updated:
  -

## Checklist

<!-- Ensure all items are completed before requesting review -->

- [ ] My code follows the project's style guidelines
- [ ] I have performed a self-review of my own code
- [ ] I have commented my code, particularly in hard-to-understand areas
- [ ] I have made corresponding changes to the documentation
- [ ] My changes generate no new warnings
- [ ] I have added tests that prove my fix is effective or that my feature works
- [ ] New and existing unit tests pass locally with my changes
- [ ] Any dependent changes have been merged and published

## Related Issues

<!-- Link to related issues -->

Fixes #(issue_number)
Closes #(issue_number)
Related to #(issue_number)

## Screenshots/Examples

<!-- If applicable, add screenshots or code examples to help explain your changes -->

## Additional Notes

<!-- Add any additional notes, concerns, or context for reviewers -->

## Reviewer Notes

<!-- Specific things you want reviewers to focus on -->

- [ ] Pay special attention to: ****\_\_\_****
- [ ] Security review needed
- [ ] Performance impact review needed
- [ ] API design review needed

---

## For Maintainers

### Pre-merge Checklist

- [ ] Code review completed
- [ ] All CI checks passing
- [ ] Documentation review completed
- [ ] No merge conflicts
- [ ] Appropriate labels applied
- [ ] Milestone assigned (if applicable)

### Post-merge Actions

- [ ] Update project version (if applicable)
- [ ] Update changelog
- [ ] Notify stakeholders
- [ ] Deploy to staging/production (if applicable)
